@@ -1,15 +1,10 @@
-## @file
-# Deprecated: use "cda" parameter instead
-
-## @class
-# Deprecated: use "cda" parameter instead
 package Lemonldap::NG::Portal::CDA;
 
 use strict;
 use Lemonldap::NG::Portal::SharedConf qw(:all);
 
-our $VERSION = '0.99.1';
-use base ('Lemonldap::NG::Portal::SharedConf');
+our $VERSION = '0.01';
+our @ISA     = ('Lemonldap::NG::Portal::SharedConf');
 
 *EXPORT_OK   = *Lemonldap::NG::Portal::SharedConf::EXPORT_OK;
 *EXPORT_TAGS = *Lemonldap::NG::Portal::SharedConf::EXPORT_TAGS;
@@ -19,15 +14,22 @@ use base ('Lemonldap::NG::Portal::SharedConf');
 # OVERLOADED SUB #
 ##################
 
-## @cmethod Lemonldap::NG::Portal::CDA new(array params)
-# Call Lemonldap::NG::Portal::SharedConf::new() with "cda" parameter set to 1
-# @param params Lemonldap::NG::Portal::SharedConf::new() parameters
-# @return New Lemonldap::NG::Portal::CDA object
-sub new {
-    my $class = shift;
-    my $self  = $class->SUPER::new(@_);
-    $self->{cda} = 1;
-    return $self;
+# 2. Existing sessions are validated so users coming from an other domain
+#    are not re-prompted
+sub existingSession {
+    my ( $self, $id, $datas ) = @_;
+    PE_DONE;
+}
+
+# 16. If the user was redirected to the portal, we will now redirect him
+#     to the requested URL. If it does not come from our domain, we add
+#     ID in URL
+sub autoRedirect {
+    my $self = shift;
+    my $tmp  = $self->{domain};
+    $self->{urldc} .= "?" . $self->{cookieName} . "=" . $self->{id}
+      if ( $self->{urldc} !~ /$tmp$/oi );
+    return $self->SUPER::autoredirect(@_);
 }
 
 1;
@@ -35,8 +37,6 @@ __END__
 
 =head1 NAME
 
-=encoding utf8
-
 Lemonldap::NG::Portal::CDA - Perl extension for building Lemonldap::NG
 compatible portals with Cross Domain Authentication.
 
@@ -44,7 +44,6 @@ compatible portals with Cross Domain Authentication.
 
   use Lemonldap::NG::Portal::SharedConf;
   my $portal = new Lemonldap::NG::Portal::SharedConf( {
-         cda => 1,
          configStorage => {
              type        => 'DBI',
              dbiChain    => "dbi:mysql:...",
@@ -57,7 +56,7 @@ compatible portals with Cross Domain Authentication.
   if($portal->process()) {
     # Write here the menu with CGI methods. This page is displayed ONLY IF
     # the user was not redirected here.
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see L<CGI(3)>)
+    print $portal->header; # DON'T FORGET THIS (see L<CGI(3)>)
     print "...";
 
     # or redirect the user to the menu
@@ -67,7 +66,7 @@ compatible portals with Cross Domain Authentication.
     # Write here the html form used to authenticate with CGI methods.
     # $portal->error returns the error message if athentification failed
     # Warning: by defaut, input names are "user" and "password"
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see L<CGI(3)>)
+    print $portal->header; # DON'T FORGET THIS (see L<CGI(3)>)
     print "...";
     print '<form method="POST">';
     # In your form, the following value is required for redirection
@@ -88,29 +87,21 @@ Modify your httpd.conf:
 
 =head1 DESCRIPTION
 
-This file is maintened only for compatibility. Now set "cda => 1" in the
-portal.
+This library just overload few methods of L<>Lemonldap::NG::Portal::SharedConf>
+to add Cross Domain Authentication. Handlers that are not used in the same
+domain than the portal must inherit from L<>Lemonldap::NG::Handler::CDA>.
+
+See L<Lemonldap::NG::Portal::SharedConf> for usage and other methods.
 
 =head1 SEE ALSO
 
 L<Lemonldap::NG::SharedConf>, L<Lemonldap::NG::Handler>,
-L<Lemonldap::NG::Handler::CDA>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<Lemonldap::NG::Handler::CDA>
 
 =head1 AUTHOR
 
 Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=head1 BUG REPORT
-
-Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
-
-=head1 DOWNLOAD
-
-Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
